@@ -42,20 +42,21 @@ public:
 
     void slotAddressBook();
 
-    EmailAddressRequester *q;
-    KLineEdit *mLineEdit;
+    EmailAddressRequester *q = nullptr;
+    KLineEdit *mLineEdit = nullptr;
 };
 
 void EmailAddressRequester::Private::slotAddressBook()
 {
-    Akonadi::EmailAddressSelectionDialog dlg(q);
-    dlg.view()->view()->setSelectionMode(QAbstractItemView::MultiSelection);
-    if (!dlg.exec()) {
+    QPointer<Akonadi::EmailAddressSelectionDialog> dlg = new Akonadi::EmailAddressSelectionDialog(q);
+    dlg->view()->view()->setSelectionMode(QAbstractItemView::MultiSelection);
+    if (!dlg->exec()) {
+        delete dlg;
         return;
     }
 
     QStringList addressList;
-    const auto selectedAddresses = dlg.selectedAddresses();
+    const auto selectedAddresses = dlg->selectedAddresses();
     addressList.reserve(selectedAddresses.size());
     for (const Akonadi::EmailAddressSelection &selection : selectedAddresses) {
         addressList << selection.quotedEmail();
@@ -72,6 +73,7 @@ void EmailAddressRequester::Private::slotAddressBook()
     }
 
     mLineEdit->setText(text + addressList.join(QLatin1Char(',')));
+    delete dlg;
 }
 
 EmailAddressRequester::EmailAddressRequester(QWidget *parent)
@@ -94,7 +96,9 @@ EmailAddressRequester::EmailAddressRequester(QWidget *parent)
     button->setToolTip(i18n("Open Address Book"));
     layout->addWidget(button);
 
-    connect(button, SIGNAL(clicked()), this, SLOT(slotAddressBook()));
+    connect(button, &QPushButton::clicked, this, [this]() {
+        d->slotAddressBook();
+    });
     connect(d->mLineEdit, &KLineEdit::textChanged, this, &EmailAddressRequester::textChanged);
 }
 
